from xia_module_gcp_bigquery.table import Table
from xia_module_gcp_bigquery.dataset import Dataset

modules = {
    "gcp-module-dataset": "Dataset",
    "gcp-module-table": "Table"
}

__all__ = [
    "Table",
    "Dataset"
]

__version__ = "0.0.22"
